@@ -15,7 +15,10 @@
 #include <specialcollectionattribute.h>
 
 #include <KLocalizedString>
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 
 using namespace Akonadi;
 
@@ -28,7 +31,7 @@ public:
     SpecialMailCollections *mInstance = nullptr;
 };
 
-typedef SpecialMailCollectionsSettings Settings;
+using Settings = SpecialMailCollectionsSettings;
 
 Q_GLOBAL_STATIC(SpecialMailCollectionsPrivate, sInstance)
 
@@ -64,10 +67,11 @@ SpecialMailCollectionsPrivate::~SpecialMailCollectionsPrivate()
 
 static KCoreConfigSkeleton *getConfig(const QString &filename)
 {
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("specialmailcollection"));
     migrate.setConfigFiles(QStringList() << filename);
     migrate.migrate();
-
+#endif
     Settings::instance(ServerManager::addNamespace(filename));
     return Settings::self();
 }
