@@ -4,14 +4,14 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SPECIALMAILCOLLECTIONSDISCOVERYJOB_H
-#define SPECIALMAILCOLLECTIONSDISCOVERYJOB_H
+#pragma once
 
 #include "akonadi-mime_export.h"
 
 #include <specialcollectionsdiscoveryjob.h>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class AKONADI_MIME_EXPORT SpecialMailCollectionsDiscoveryJob : public SpecialCollectionsDiscoveryJob
 {
     Q_OBJECT
@@ -20,4 +20,3 @@ public:
 };
 }
 
-#endif /* SPECIALMAILCOLLECTIONSDISCOVERYJOB_H */
